| RCLF | R Documentation |
Datasets for match results for four Scottish clubs: Rangers, Celtic, Livingston, Falkirk.
data(RCLF)
These objects refer to results from football matches among four
Scottish clubs: Rangers, Celtic, Livingston, Falkirk. A detailed
analysis is presented in inst/home_advantage.Rmd, which creates
the objects documented here from scratch.
Object RCLF3_table is a table of results for the four
clubs: home wins, draws, and away wins.
RCLF3_lambda_max for the maximum likelihood estimate for
\lambda.
Object RCLF3 is a hyper3 likelihood function for
the table of won games only [that is, excluding draws], using
RCLF3_lambda_max for the value of \lambda.
Object RCLF3_maxp is its evaluate at the MLE for
lambda
The objects are created by inst/home_advantage.Rmd.
Robin K. S. Hankin
Data obtained from www.worldfootball.net
data(RCLF)
RCLF3_table
RCLF3_maxp
RCLF3_lambda_max
loglik(RCLF3_maxp,RCLF3)
equalp.test(RCLF3)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.