javelin: Javelin dataset

javelinR Documentation

Javelin dataset

Description

An attemptstable object showing results from the men's javelin, 2020 Summer Olympics.

Usage

data(javelin)

Details

  • javelin_table, an attemptstable object detailing the throw distances of eight competitors (diacritics have been removed) for each of six throws

  • javelin1 and javelin2, support functions corresponding to the weighted Plackett-Luce likelihood. The suffix “2” means that no-throws are counted as losing attempts; otherwise, no-throws are ignored.

  • javelin_maxp and javelin2_maxp are the corresponding maximum likelihood estimates for the players' strengths

  • javelin_vector is a named vector with elements being the throw distances and names being the thrower

These objects can be generated by running script inst/javelin.Rmd, which includes some further discussion and technical documentation, and creates file javelin.rda which resides in the data/ directory.

Note

The format for Olympic javelin results is common to six of the field events: long jump, triple jump, shot put, discus throw, hammer throw, and javelin (high jump and long jump have a different format). The inst/ directory on github includes some other datasets such as olympics_2020_womens_shotput.txt in the same form as inst/javelin.txt.

Author(s)

Robin K. S. Hankin

See Also

attemptstable2supp3

Examples


attemptstable2supp3(javelin_table)

pie(javelin_maxp)


hyper2 documentation built on June 23, 2026, 5:07 p.m.