powered by
hyper2
Random hyper2 loglikelihood functions, intended as quick “get you going” examples
rhyper2(n = 8, s = 5, pairs = TRUE, teams = TRUE, race = TRUE, pnames)
Number of competitors, treated as even
Integer, Measure of the complexity of the log likelihood function
Boolean, indicating whether or not to include different observations
Character vector of names, if missing interpret as letters; set to NA meaning no names
letters
NA
rp
# NOT RUN { dotchart(maxp(rhyper2(n=8,s=10))) dotchart(maxp(rhyper2(n=26,s=2,race=FALSE))) # }
Run the code above in your browser using DataLab