rrace: A random race with given BT strengths

rraceR Documentation

A random race with given BT strengths

Description

Returns a rank vector suitable for interpretation with race().

Usage

rrace(strengths)

Arguments

strengths

Named vector with names being players and values being their Bradley-Terry strengths

Details

Uses a simple recursive system to generate the ranks.

Value

Returns a character vector with entries corresponding to the competitor. The first element is the winner, the second the runner-up, and so on, until the final element is the last to cross the finishing line.

Author(s)

Robin K. S. Hankin

See Also

rrace3,hyper2

Examples


o <- c(a=0.4, b=0.3, c=0.2, d=0.1)
rrace(o)

suppfun(rrace(o))

table(replicate(100,rrace(o)[1]))  # should be about 40% "a"

as.ranktable(t(replicate(10, rrace(o)))) # same as rrank(10,o)


hyper2 documentation built on June 23, 2026, 5:07 p.m.