| skating | R Documentation |
A likelihood function for the competitors at the Ladies' Free Skate at the 2002 Winter Olympics
skating
Three objects: skating, a log-likelihood function for the
competitors' strengths, skating_table, an order table for each
of the 9 judges, and skating_maxp, the result of
maxp(skating), which is included to save time in the examples.
These objects can be generated by running script
inst/skating.Rmd, which includes some further discussion and
technical documentation. The dataset is interesting because it has
been analysed by many workers, including Lock and Lock, for
consistency between the judges.
Note that skating_table is an order table: it is structured so
that each competitor is a row, and each judge is a column. Function
suppfun() requires a rank table [use as.ranktable() to
coerce; see the examples]. Object skating_table is taken from
Lock and Lock. It corrects what appears to be an error in which judge
5 ranked both Butyrskaya and Kettunen 12; there is no 13. Using
EM, I reckon that Butyrskaya should be ranked twelfth and
Kettunen thirteenth.
There is an (Rbuildignore-d) discussion of a
skeleton dataset in the inst/ directory of the repo,
it's easy to confuse this with skating.
Robin K. S. Hankin
https://en.wikipedia.org/wiki/Figure_skating_at_the_2002_Winter_Olympics#Full_results_2
Robin Lock and Kari Frazer Lock, Winter 2003. “Judging Figure Skating Judges”. STATS 36, ASA
data(skating)
dotchart(skating_maxp)
as.ranktable(skating_table)
suppfun(as.ranktable(skating_table))
rL <- sort(skating_maxp, decreasing=TRUE)
rL[] <- seq_along(rL)
rO <- seq_len(nrow(skating_table))
names(rO) <- rownames(skating_table)
ordertransplot(rO,rL,
xlab="official rank",ylab="likelihood rank",
main="Ladies free skating, 2002 Winter Olympics")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.