surfing: Surfing dataset

surfingR Documentation

Surfing dataset

Description

Data from the 2019 World Surf League (WSL) tour

Usage

data(surfing)

Details

The package contains four datasets from WSL 2019:

  • surfing, a log likelihood function for the strengths of the competitors

  • surfing_maxp, corresponding precalculated evaluate

  • surfing_venuetypes, a dataframe showing the beach types at the different venues of the tour

These objects can be generated by running script inst/surfing.Rmd, which includes some further discussion and technical documentation and creates file surfing.rda which resides in the data/ directory.

Author(s)

Robin K. S. Hankin

References

T. C. Driver and R. K. S. Hankin 2023. “Analysis of competitive surfing tournaments with generalized Bradley-Terry likelihoods”, Journal of Sports Analytics, 9:133–140. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.3233/JSA-220596")}

Examples

dotchart(surfing_maxp)


hyper2 documentation built on June 23, 2026, 5:07 p.m.