Learn R Programming

hyper2 (version 3.2)

sushi: Sushi dataset

Description

Dataset from the preflib website, discussing sushi preferences.

Usage

data(sushi)

Arguments

Details

Sushi preference dataset.

  • Object sushi_table is a database of sushi preferences; each row is a judge and the rows are rank vectors of the different sushi types.

  • Object sushi is a likelihood function at the estimated value of lambda

  • Object sushi_maxp is the maximum likelihood estimate for the Bradley-Terry strengths of the sushis, at the estimate for lambda.

  • sushi_eq_classes is a named vector giving the equivalences classes of sushi. Class 1 is tuna, class 2 is everything else.

These objects can be generated by running script inst/sushi.Rmd, which includes some further discussion and technical documentation and creates file sushi.rda which resides in the data/ directory.

Examples

Run this code
sushi
sushi_maxp

Run the code above in your browser using DataLab