| table_tennis | R Documentation |
Match outcomes from repeated singles table tennis matches
data(table_tennis)
A likelihood function corresponding to the match outcomes listed below.
There are four players, A, B, and C, who play singles table tennis matches with the following results:
A vs B, A serves, 5-1
A vs B, B serves, 1-3
A vs C, A serves, 4-1
A vs C, C serves, 1-2
Object table_tennis is a hyper2 log-likelihood function
for these observations; S is the strength of the serving ghost.
Probability vector table_tennis_maxp is the maximum likelihood
estimate.
These objects can be generated by running script
inst/table_tennis_serve.Rmd, which includes some further
discussion and technical documentation and creates file
table_tennnis.rda which resides in the data/ directory.
data(table_tennis)
dotchart(table_tennis_maxp)
specificp.gt.test(table_tennis, "S", 0)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.